package com.radxa.com.radxa_gpio;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import java.util.ArrayList;
import java.util.List;
import  android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.radxa.com.radxa_gpio_demo.R;

import static android.widget.AdapterView.*;

public class GpioTest extends Activity {
    private Spinner mSpinner;
    private List<String> mData_list;
    private ArrayAdapter<String> mArr_adapter;
    private String TAG = "GpioTest";

    Button mButtonWrite;
    Button mButtonRead;
    TextView mValueText;
    TextView mGpioText;

    // kernel version 3.0.36+
    /**
     * J8
     * 167,169,188,189,190,191,192,193,194,202,203,204,205,217,216,284,285
     * J12/J15
     * 196,197,198,199,207,286
     */
    private int mSelectGpioNum = 168;
    private int mSelectGpioValue = 0;
    private GpioUtil mGpioUtil;

    final String DEV_NAME = "/dev/gpioctl_radxa";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_gpiotest);
        mSpinner = (Spinner)findViewById(R.id.spinner);
        mButtonWrite = (Button)findViewById(R.id.write_gpio);
        mButtonRead = (Button)findViewById(R.id.read_gpio);

        mButtonRead.setOnClickListener(mOnClickListener);
        mButtonWrite.setOnClickListener(mOnClickListener);

        mValueText = (TextView)findViewById(R.id.value);
        mGpioText = (TextView)findViewById(R.id.gpio);
        mGpioText.setText(" " + mSelectGpioNum);

        mGpioUtil = new GpioUtil();
        mGpioUtil.openDev(DEV_NAME);
        initList();

        mArr_adapter= new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, mData_list);
        mArr_adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        mSpinner.setAdapter(mArr_adapter);
        mSpinner.setOnItemSelectedListener(mOnItemSelectedListener);
    }

    OnItemSelectedListener mOnItemSelectedListener = new OnItemSelectedListener() {
        @Override
        public void onItemSelected(AdapterView<?> adapterView, View view, int position, long id) {
                switch (adapterView.getId()){
                    case R.id.spinner:
                        mSelectGpioValue = position;
                        showToast("select item mSelectGpioValue = " + mSelectGpioValue);
                        break;
                    default:
                        Log.d(TAG,"onItemSelected");
                }
        }

        @Override
        public void onNothingSelected(AdapterView<?> adapterView) {

        }
    };

    View.OnClickListener mOnClickListener = new View.OnClickListener(){
        @Override
        public void onClick(View view) {
            switch (view.getId()) {
                case R.id.write_gpio:
                    Log.d(TAG,"click write_gpio");
                    int ret = 0;
                    if(null != mGpioUtil) {
                        ret = mGpioUtil.setVal(mSelectGpioNum, mSelectGpioValue);
                        if(ret < 0){
                            showToast("write gpio failed, gpio is occupied");
                        }
                    }
                    break;
                case R.id.read_gpio:
                    Log.d(TAG,"click read_gpio");
                    if(null != mGpioUtil) {
                        int value = mGpioUtil.getVal(mSelectGpioNum);
                        mValueText.setText("   "+value);
                    }
                    break;
            }
        }
    };

    private void initList(){
        mData_list = new ArrayList<String>();

        if(null == mGpioUtil){
            return;
        }

        mData_list = new ArrayList<String>();
        mData_list.add(" " + 0);
        mData_list.add(" " + 1);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        Log.d(TAG, "onDestory");
        if(null != mGpioUtil){
            if(mGpioUtil.isRequested && false == mGpioUtil.isOccupiedByOther) {
                mGpioUtil.releaseGpio(mSelectGpioNum);
            }
            mGpioUtil.closeDev();
        }
    }

    private void showToast(String msg){
        Toast.makeText(getApplicationContext(), msg,
                Toast.LENGTH_SHORT).show();
    }
}
